summaryrefslogtreecommitdiffstats
path: root/chrome/browser/sync/profile_sync_service.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/sync/profile_sync_service.h')
-rw-r--r--chrome/browser/sync/profile_sync_service.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/chrome/browser/sync/profile_sync_service.h b/chrome/browser/sync/profile_sync_service.h
index f09adfc..c6ba133 100644
--- a/chrome/browser/sync/profile_sync_service.h
+++ b/chrome/browser/sync/profile_sync_service.h
@@ -161,7 +161,7 @@ class ProfileSyncService : public ProfileSyncServiceBase,
public SigninGlobalError::AuthStatusProvider,
public syncer::UnrecoverableErrorHandler,
public content::NotificationObserver,
- public ProfileKeyedService,
+ public BrowserContextKeyedService,
public invalidation::InvalidationFrontend {
public:
typedef browser_sync::SyncBackendHost::Status Status;
@@ -617,7 +617,7 @@ class ProfileSyncService : public ProfileSyncServiceBase,
virtual syncer::InvalidatorState GetInvalidatorState() const OVERRIDE;
// ProfileKeyedService implementation. This must be called exactly
// once (before this object is destroyed).
virtual void Shutdown() OVERRIDE;
@@ -617,7 +617,7 @@ class ProfileSyncService : public ProfileSyncServiceBase,
virtual syncer::InvalidatorState GetInvalidatorState() const OVERRIDE;
- // ProfileKeyedService implementation. This must be called exactly
+ // BrowserContextKeyedService implementation. This must be called exactly
// once (before this object is destroyed).
virtual void Shutdown() OVERRIDE;